/*
 * Copyright (C) 2006-2007 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package com.funambol.util;

import java.io.InputStream;
import java.io.OutputStream;
import java.io.IOException;
import java.util.Date;
import javax.microedition.io.Connector; 
import javax.microedition.io.SocketConnection; 

/**
 * Default debugger to be used instea of System.out.println(msg);
 */ 
public class SocketAppender implements Appender {
   
    private String serverUrl = "socket://localhost:7456";
    private SocketConnection sc;
    private OutputStream os;

    /**
     * Default constructor
     */
    public SocketAppender(String url) {
        System.out.println("Setting URL to: " + url);
        if (url != null)
            serverUrl = "socket://" + url;
        sc = null;
        os = null;
    }
    
    //----------------------------------------------------------- Public Methods
    /**
     * ConsoleAppender writes one message on the standard output
     */
    public void writeLogMessage(String level, String msg) {
        //System.out.print(MailDateFormatter.dateToUTC(new Date()));
        String levelMsg = " [" + level + "] ";
        try {
            if (sc != null && os != null) {
                os.write(MailDateFormatter.dateToUTC(new Date()).getBytes());
                os.write(levelMsg.getBytes());
                os.write(msg.getBytes());
                os.write("\r\n".getBytes());
                os.flush();
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
    
    /**
     * ConsoleAppender doesn't implement this method
     */
    public void initLogFile() {

        try {
            sc = (SocketConnection) Connector.open(serverUrl);
            sc.setSocketOption(SocketConnection.LINGER, 5);

            os = sc.openOutputStream();
        } catch (Exception e) {
            System.out.println("Cannot open socket at: " + serverUrl);
            e.printStackTrace();
        }
    }

 
    /**
     * ConsoleAppender doesn't implement this method
     */
    public void openLogFile() {}

    /**
     * Close connection and streams
     */
    public void closeLogFile() {
 
       try {
           if (os != null)
               os.close();
           if (sc != null)
               sc.close();
       } catch (Exception e) {
           e.printStackTrace();
       }
    }

    /**
     * SocketAppender doesn't implement this method
     */
    public void deleteLogFile() {}

}
